Authors
=======

Core Development
----------------
::

    David M. Burns MD, PhD(c)
    Sunnybrook Research Institute
    University of Toronto
    Email: david.mo.burns@gmail.com

Contributors
------------
::

    - Matthias Gazzari: mail@qtux.eu